# Generated by Django 3.0.5 on 2020-05-03 03:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('countries', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='country',
            options={'permissions': (('list_country', 'Can list countries'),)},
        ),
    ]
