# Generated by Django 3.0.5 on 2020-04-02 16:51

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('auth', '0011_update_proxy_permissions'),
    ]

    operations = [
        migrations.CreateModel(
            name='PermissionPlus',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=200, null=True)),
                ('active', models.BooleanField(default=False)),
                ('permission', models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='plus', to='auth.Permission')),
            ],
        ),
    ]
