# Generated by Django 3.0.5 on 2020-04-02 13:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('users_extended', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='extendeduser',
            name='security_pin',
            field=models.CharField(max_length=300, null=True),
        ),
    ]
