# Generated by Django 3.0.5 on 2020-04-02 12:53

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import imagekit.models.fields
import users_extended.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='ExtendedUser',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('profile_image', imagekit.models.fields.ProcessedImageField(blank=True, null=True, upload_to=users_extended.models.ExtendedUser.profile_image_upload_to)),
                ('security_pin', models.PositiveIntegerField(null=True)),
                ('security_qr', models.CharField(max_length=300, null=True)),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='extended_user', to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
