# Generated by Django 3.0.5 on 2020-04-25 14:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('users_extended', '0008_auto_20200422_1706'),
    ]

    operations = [
        migrations.AddField(
            model_name='extendeduser',
            name='multi_sessions',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='extendeduser',
            name='multi_sessions_qty',
            field=models.PositiveIntegerField(default=0),
        ),
    ]
