# Generated by Django 3.0.5 on 2020-04-04 16:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('permissions', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='permissionplus',
            options={'permissions': (('list_permission', 'Can list permission'), ('list_group', 'Can list group'))},
        ),
    ]
