# Generated by Django 3.0.5 on 2020-04-22 13:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('users_extended', '0006_auto_20200405_2103'),
    ]

    operations = [
        migrations.AddField(
            model_name='extendeduser',
            name='alias',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
    ]
